@@ -152,20 +152,21 @@ def paragraph_close(
     # Make sure a paragraph line does not start with "#"
     # (otherwise it will be interpreted as an ATX heading).
     lines = [f"\\{line}" if line.startswith("#") else line for line in lines]
-    # Make sure a paragraph line does not start with "-" or "+"
+    # Make sure a paragraph line does not start with "*", "-" or "+"
+    # followed by a space, tab, or end of line.
     # (otherwise it will be interpreted as list item).
     lines = [
-        f"\\{line}" if (line.startswith("-") or line.startswith("+")) else line
-        for line in lines
+        f"\\{line}" if re.match(r"[-*+]( |\t|$)", line) else line for line in lines
     ]
-    # If a line starts with a number followed by "." or ")", escape the "." or
-    # ")" or it will be interpreted as ordered list item.
+    # If a line starts with a number followed by "." or ")" followed by
+    # a space, tab or end of line, escape the "." or ")" or it will be
+    # interpreted as ordered list item.
     lines = [
-        line.replace(")", "\\)", 1) if re.match(r"[0-9]+\)", line) else line
+        line.replace(")", "\\)", 1) if re.match(r"[0-9]+\)( |\t|$)", line) else line
         for line in lines
     ]
     lines = [
-        line.replace(".", "\\.", 1) if re.match(r"[0-9]+\.", line) else line
+        line.replace(".", "\\.", 1) if re.match(r"[0-9]+\.( |\t|$)", line) else line
         for line in lines
     ]
 
